<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.valentinog.com
 * @since      1.0.0
 *
 * @package    Enquiry_Woo
 * @subpackage Enquiry_Woo/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Enquiry_Woo
 * @subpackage Enquiry_Woo/admin
 * @author     Valentino Gagliardi <valentino@valentinog.com>
 */
class Enquiry_Woo_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The slug name for this menu / The menu page on which to display this section
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $page    The slug name for this menu
	 */
	private $page;

	/**
	 * The ??
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $post_type    The ??
	 */
	 private $post_type;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->page = 'enquiry-woo';
		$this->post_type = 'wpcf7_contact_form';

	}

	/**
	 * add doc
	 * This function gets called inside includes/class-enquiry-woo.php in define_admin_hooks()
	 */

	public function create_settings_page_enquiry_woo() {
		add_submenu_page(
			'options-general.php',
			__('Enquiry Woo Settings', 'enquiry-woo'),
			__('Enquiry Woo', 'enquiry-woo'),
			'manage_options',
			$this->page,
			array( $this, 'settings_page_enquiry_woo_cb' )
			);
	}

	/**
	* add doc
	 */

	public function settings_page_enquiry_woo_cb() {
		if (!current_user_can('manage_options')) {
			return;
		}
		?>
	<div class="wrap">
		<h2>Enquiry Woo Settings</h2>
		<form method="post" action="options.php">
			<?php
				 do_settings_sections($this->page);
				 settings_fields($this->page);
				 submit_button();
			 ?>
		</form>
	</div>
	<?php
	 }

	/**
	* add doc
	* This function gets called inside includes/class-enquiry-woo.php in define_admin_hooks()
	*/
	
	public function setup_settings_section_enquiry_woo() {
		add_settings_section(
			'form_selection',
			__('Contact form selection', 'enquiry-woo'),
			array( $this, 'setup_sections_enquiry_woo_cb' ),
			$this->page
		);
	 }
	
	/**
	* add doc
	*/

	public function setup_sections_enquiry_woo_cb( $arguments ) {
		switch ($arguments['id']) {
			case 'form_selection':
				printf( __('%1$s Here you can choose which form to display %2$s', 'enquiry-woo'), '<p>', '</p>' );
				break;
		}
	}

	/**
	* add doc
	* This function gets called inside includes/class-enquiry-woo.php in define_admin_hooks()
	*/

	public function setup_fields_enquiry_woo() {
		add_settings_field(
			'enquiry_woo_form_selection_field',
			__('Pick a form', 'enquiry-woo'),
			array( $this, 'form_selection_enquiry_woo_field_cb'),
			$this->page,
			'form_selection'
		);		
	}

	/**
	* add doc
	*/

	public function form_selection_enquiry_woo_field_cb() {
		?>
		<select name="enquiry_woo_form_selection_field" id="enquiry_woo_form_selection_field">
		<?php
			$args = array( 'post_type' => $this->post_type );
			$posts = get_posts( $args );
				foreach ( $posts as $post ) : setup_postdata( $post ); 
					$title = apply_filters( 'the_title', $post->post_title );
					$id = apply_filters( 'ID', $post->ID );
					?>
					<option value="<?php echo $title . ',' . $id; ?>" >
						<?php echo $title; ?>
					</option>
				<?php endforeach;
		?>
			</select>
		<?php
	}

	/**
	* add doc
	* This function gets called inside includes/class-enquiry-woo.php in define_admin_hooks()
	*/

	public function register_settings_enquiry_woo() {
		register_setting($this->page, 'enquiry_woo_form_selection_field');
	}

}