<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.valentinog.com
 * @since      1.0.0
 *
 * @package    Enquiry_Woo
 * @subpackage Enquiry_Woo/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Enquiry_Woo
 * @subpackage Enquiry_Woo/public
 * @author     Valentino Gagliardi <valentino@valentinog.com>
 */
class Enquiry_Woo_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Adds a new tab to every Woocommerce product
	 *
	 * @since    1.0.0
	 * @param array $tabs Woocommerce tabs
	 */

	public function add_enquiry_tab_enquiry_woo( $tabs ) {
		$info_msg = __('Request info', 'enquiry-woo');
		$tabs['enquiry_woo_tab'] = array(
			'title' => $info_msg,
			'priority' => 50,
			'callback' => array($this, 'add_enquiry_tab_enquiry_woo_cb')
		);

		return $tabs;
	}

	public function add_enquiry_tab_enquiry_woo_cb() {
		$string = get_option('enquiry_woo_form_selection_field');
		$contact_form_id = explode(',', $string)[1];
		$contact_form_title = explode(',', $string)[0];
		$cf7_shortcode = sprintf( '[contact-form-7 id="%1$d" title="%2$s"]', $contact_form_id, $contact_form_title );
		echo do_shortcode($cf7_shortcode);
	}

}